@@ -7,25 +7,16 @@
 #include <aws/ce/CostExplorer_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 
-namespace Aws
-{
-namespace CostExplorer
-{
-namespace Model
-{
-  enum class CostAllocationTagType
-  {
-    NOT_SET,
-    AWSGenerated,
-    UserDefined
-  };
+namespace Aws {
+namespace CostExplorer {
+namespace Model {
+enum class CostAllocationTagType { NOT_SET, AWSGenerated, UserDefined };
 
-namespace CostAllocationTagTypeMapper
-{
+namespace CostAllocationTagTypeMapper {
 AWS_COSTEXPLORER_API CostAllocationTagType GetCostAllocationTagTypeForName(const Aws::String& name);
 
 AWS_COSTEXPLORER_API Aws::String GetNameForCostAllocationTagType(CostAllocationTagType value);
-} // namespace CostAllocationTagTypeMapper
-} // namespace Model
-} // namespace CostExplorer
-} // namespace Aws
+}  // namespace CostAllocationTagTypeMapper
+}  // namespace Model
+}  // namespace CostExplorer
+}  // namespace Aws
