@@ -7,25 +7,16 @@
 #include <aws/chime-sdk-meetings/ChimeSDKMeetings_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 
-namespace Aws
-{
-namespace ChimeSDKMeetings
-{
-namespace Model
-{
-  enum class MeetingFeatureStatus
-  {
-    NOT_SET,
-    AVAILABLE,
-    UNAVAILABLE
-  };
+namespace Aws {
+namespace ChimeSDKMeetings {
+namespace Model {
+enum class MeetingFeatureStatus { NOT_SET, AVAILABLE, UNAVAILABLE };
 
-namespace MeetingFeatureStatusMapper
-{
+namespace MeetingFeatureStatusMapper {
 AWS_CHIMESDKMEETINGS_API MeetingFeatureStatus GetMeetingFeatureStatusForName(const Aws::String& name);
 
 AWS_CHIMESDKMEETINGS_API Aws::String GetNameForMeetingFeatureStatus(MeetingFeatureStatus value);
-} // namespace MeetingFeatureStatusMapper
-} // namespace Model
-} // namespace ChimeSDKMeetings
-} // namespace Aws
+}  // namespace MeetingFeatureStatusMapper
+}  // namespace Model
+}  // namespace ChimeSDKMeetings
+}  // namespace Aws
