@@ -8,16 +8,13 @@
 #include <aws/codestar-notifications/CodeStarNotifications_EXPORTS.h>
 #include <aws/core/client/AWSErrorMarshaller.h>
 
-namespace Aws
-{
-namespace Client
-{
+namespace Aws {
+namespace Client {
 
-class AWS_CODESTARNOTIFICATIONS_API CodeStarNotificationsErrorMarshaller : public Aws::Client::JsonErrorMarshaller
-{
-public:
+class AWS_CODESTARNOTIFICATIONS_API CodeStarNotificationsErrorMarshaller : public Aws::Client::JsonErrorMarshaller {
+ public:
   Aws::Client::AWSError<Aws::Client::CoreErrors> FindErrorByName(const char* exceptionName) const override;
 };
 
-} // namespace Client
-} // namespace Aws
+}  // namespace Client
+}  // namespace Aws
