@@ -12,6 +12,7 @@
 #include <aws/datazone/model/EnvironmentDeploymentDetails.h>
 #include <aws/datazone/model/ProjectDeletionError.h>
 #include <aws/datazone/model/ProjectStatus.h>
+#include <aws/datazone/model/ResourceTag.h>
 
 #include <utility>
 
@@ -265,6 +266,29 @@ class UpdateProjectResult {
   }
   ///@}
 
+  ///@{
+  /**
+   * <p>The resource tags of the project.</p>
+   */
+  inline const Aws::Vector<ResourceTag>& GetResourceTags() const { return m_resourceTags; }
+  template <typename ResourceTagsT = Aws::Vector<ResourceTag>>
+  void SetResourceTags(ResourceTagsT&& value) {
+    m_resourceTagsHasBeenSet = true;
+    m_resourceTags = std::forward<ResourceTagsT>(value);
+  }
+  template <typename ResourceTagsT = Aws::Vector<ResourceTag>>
+  UpdateProjectResult& WithResourceTags(ResourceTagsT&& value) {
+    SetResourceTags(std::forward<ResourceTagsT>(value));
+    return *this;
+  }
+  template <typename ResourceTagsT = ResourceTag>
+  UpdateProjectResult& AddResourceTags(ResourceTagsT&& value) {
+    m_resourceTagsHasBeenSet = true;
+    m_resourceTags.emplace_back(std::forward<ResourceTagsT>(value));
+    return *this;
+  }
+  ///@}
+
   ///@{
   /**
    * <p>The user parameters of the project.</p>
@@ -342,6 +366,9 @@ class UpdateProjectResult {
   ProjectStatus m_projectStatus{ProjectStatus::NOT_SET};
   bool m_projectStatusHasBeenSet = false;
 
+  Aws::Vector<ResourceTag> m_resourceTags;
+  bool m_resourceTagsHasBeenSet = false;
+
   Aws::Vector<EnvironmentConfigurationUserParameter> m_userParameters;
   bool m_userParametersHasBeenSet = false;
 
