@@ -4,27 +4,19 @@
  */
 
 #pragma once
-#include <aws/frauddetector/FraudDetector_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/frauddetector/FraudDetector_EXPORTS.h>
 
-namespace Aws
-{
-namespace FraudDetector
-{
-namespace Model
-{
-  enum class ModelSource
-  {
-    NOT_SET,
-    SAGEMAKER
-  };
+namespace Aws {
+namespace FraudDetector {
+namespace Model {
+enum class ModelSource { NOT_SET, SAGEMAKER };
 
-namespace ModelSourceMapper
-{
+namespace ModelSourceMapper {
 AWS_FRAUDDETECTOR_API ModelSource GetModelSourceForName(const Aws::String& name);
 
 AWS_FRAUDDETECTOR_API Aws::String GetNameForModelSource(ModelSource value);
-} // namespace ModelSourceMapper
-} // namespace Model
-} // namespace FraudDetector
-} // namespace Aws
+}  // namespace ModelSourceMapper
+}  // namespace Model
+}  // namespace FraudDetector
+}  // namespace Aws
