@@ -4,31 +4,19 @@
  */
 
 #pragma once
-#include <aws/gameliftstreams/GameLiftStreams_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/gameliftstreams/GameLiftStreams_EXPORTS.h>
 
-namespace Aws
-{
-namespace GameLiftStreams
-{
-namespace Model
-{
-  enum class ApplicationStatus
-  {
-    NOT_SET,
-    INITIALIZED,
-    PROCESSING,
-    READY,
-    DELETING,
-    ERROR_
-  };
+namespace Aws {
+namespace GameLiftStreams {
+namespace Model {
+enum class ApplicationStatus { NOT_SET, INITIALIZED, PROCESSING, READY, DELETING, ERROR_ };
 
-namespace ApplicationStatusMapper
-{
+namespace ApplicationStatusMapper {
 AWS_GAMELIFTSTREAMS_API ApplicationStatus GetApplicationStatusForName(const Aws::String& name);
 
 AWS_GAMELIFTSTREAMS_API Aws::String GetNameForApplicationStatus(ApplicationStatus value);
-} // namespace ApplicationStatusMapper
-} // namespace Model
-} // namespace GameLiftStreams
-} // namespace Aws
+}  // namespace ApplicationStatusMapper
+}  // namespace Model
+}  // namespace GameLiftStreams
+}  // namespace Aws
