@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/kendra/Kendra_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/kendra/Kendra_EXPORTS.h>
 
-namespace Aws
-{
-namespace kendra
-{
-namespace Model
-{
-  enum class WebCrawlerMode
-  {
-    NOT_SET,
-    HOST_ONLY,
-    SUBDOMAINS,
-    EVERYTHING
-  };
+namespace Aws {
+namespace kendra {
+namespace Model {
+enum class WebCrawlerMode { NOT_SET, HOST_ONLY, SUBDOMAINS, EVERYTHING };
 
-namespace WebCrawlerModeMapper
-{
+namespace WebCrawlerModeMapper {
 AWS_KENDRA_API WebCrawlerMode GetWebCrawlerModeForName(const Aws::String& name);
 
 AWS_KENDRA_API Aws::String GetNameForWebCrawlerMode(WebCrawlerMode value);
-} // namespace WebCrawlerModeMapper
-} // namespace Model
-} // namespace kendra
-} // namespace Aws
+}  // namespace WebCrawlerModeMapper
+}  // namespace Model
+}  // namespace kendra
+}  // namespace Aws
