@@ -23,6 +23,7 @@
 #include <aws/lambda/model/SnapStartResponse.h>
 #include <aws/lambda/model/State.h>
 #include <aws/lambda/model/StateReasonCode.h>
+#include <aws/lambda/model/TenancyConfig.h>
 #include <aws/lambda/model/TracingConfigResponse.h>
 #include <aws/lambda/model/VpcConfigResponse.h>
 
@@ -750,6 +751,26 @@ class FunctionConfiguration {
   }
   ///@}
 
+  ///@{
+  /**
+   * <p>The function's tenant isolation configuration settings. Determines whether
+   * the Lambda function runs on a shared or dedicated infrastructure per unique
+   * tenant.</p>
+   */
+  inline const TenancyConfig& GetTenancyConfig() const { return m_tenancyConfig; }
+  inline bool TenancyConfigHasBeenSet() const { return m_tenancyConfigHasBeenSet; }
+  template <typename TenancyConfigT = TenancyConfig>
+  void SetTenancyConfig(TenancyConfigT&& value) {
+    m_tenancyConfigHasBeenSet = true;
+    m_tenancyConfig = std::forward<TenancyConfigT>(value);
+  }
+  template <typename TenancyConfigT = TenancyConfig>
+  FunctionConfiguration& WithTenancyConfig(TenancyConfigT&& value) {
+    SetTenancyConfig(std::forward<TenancyConfigT>(value));
+    return *this;
+  }
+  ///@}
+
   ///@{
 
   inline const Aws::String& GetRequestId() const { return m_requestId; }
@@ -874,6 +895,9 @@ class FunctionConfiguration {
   LoggingConfig m_loggingConfig;
   bool m_loggingConfigHasBeenSet = false;
 
+  TenancyConfig m_tenancyConfig;
+  bool m_tenancyConfigHasBeenSet = false;
+
   Aws::String m_requestId;
   bool m_requestIdHasBeenSet = false;
 };
