@@ -6,6 +6,7 @@
 #pragma once
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/lexv2-models/LexModelsV2_EXPORTS.h>
+#include <aws/lexv2-models/model/SpeechDetectionSensitivity.h>
 #include <aws/lexv2-models/model/VoiceSettings.h>
 
 #include <utility>
@@ -135,6 +136,24 @@ class BotLocaleImportSpecification {
     return *this;
   }
   ///@}
+
+  ///@{
+  /**
+   * <p>The sensitivity level for voice activity detection (VAD) in the bot locale.
+   * This setting helps optimize speech recognition accuracy by adjusting how the
+   * system responds to background noise during voice interactions.</p>
+   */
+  inline SpeechDetectionSensitivity GetSpeechDetectionSensitivity() const { return m_speechDetectionSensitivity; }
+  inline bool SpeechDetectionSensitivityHasBeenSet() const { return m_speechDetectionSensitivityHasBeenSet; }
+  inline void SetSpeechDetectionSensitivity(SpeechDetectionSensitivity value) {
+    m_speechDetectionSensitivityHasBeenSet = true;
+    m_speechDetectionSensitivity = value;
+  }
+  inline BotLocaleImportSpecification& WithSpeechDetectionSensitivity(SpeechDetectionSensitivity value) {
+    SetSpeechDetectionSensitivity(value);
+    return *this;
+  }
+  ///@}
  private:
   Aws::String m_botId;
   bool m_botIdHasBeenSet = false;
@@ -150,6 +169,9 @@ class BotLocaleImportSpecification {
 
   VoiceSettings m_voiceSettings;
   bool m_voiceSettingsHasBeenSet = false;
+
+  SpeechDetectionSensitivity m_speechDetectionSensitivity{SpeechDetectionSensitivity::NOT_SET};
+  bool m_speechDetectionSensitivityHasBeenSet = false;
 };
 
 }  // namespace Model
