@@ -74,6 +74,23 @@ class DescribeIntentResult {
   }
   ///@}
 
+  ///@{
+  /**
+   * <p>The display name specified for the intent.</p>
+   */
+  inline const Aws::String& GetIntentDisplayName() const { return m_intentDisplayName; }
+  template <typename IntentDisplayNameT = Aws::String>
+  void SetIntentDisplayName(IntentDisplayNameT&& value) {
+    m_intentDisplayNameHasBeenSet = true;
+    m_intentDisplayName = std::forward<IntentDisplayNameT>(value);
+  }
+  template <typename IntentDisplayNameT = Aws::String>
+  DescribeIntentResult& WithIntentDisplayName(IntentDisplayNameT&& value) {
+    SetIntentDisplayName(std::forward<IntentDisplayNameT>(value));
+    return *this;
+  }
+  ///@}
+
   ///@{
   /**
    * <p>The description of the intent.</p>
@@ -451,6 +468,9 @@ class DescribeIntentResult {
   Aws::String m_intentName;
   bool m_intentNameHasBeenSet = false;
 
+  Aws::String m_intentDisplayName;
+  bool m_intentDisplayNameHasBeenSet = false;
+
   Aws::String m_description;
   bool m_descriptionHasBeenSet = false;
 
